package com.hungraim.ltc.governance.controller;

import com.baomidou.mybatisplus.extension.plugins.pagination.Page;
import com.hungraim.ltc.governance.service.AprOrganService;
import com.hungraim.ltc.pojo.entity.serviceManage.ChAprOrgan;
import com.hungraim.ltc.pojo.vo.governance.AprOrganVO;
import com.hungraim.ltc.util.Result;
import com.hungraim.ltc.util.ResultCode;
import lombok.extern.slf4j.Slf4j;
import org.apache.commons.lang.StringUtils;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.web.bind.annotation.*;

/**
 * 评定机构及评定机构人员信息管理Controller
 *
 * @author czz
 */
@RestController
@RequestMapping("/api.governance/organ")
@Slf4j
public class AprOrganController {

    @Autowired
    private AprOrganService aprOrganService;

    /**
     * 评定机构信息列表
     *
     * @param pageNum    页码
     * @param pageSize   每页展示条数
     * @param organId    适用机构id
     * @param isIncluded 是否包含下级机构,值为true，则包含organId的下层机构
     * @param organName  机构名称
     * @param code       统一社会信用代码
     */
    @RequestMapping("/aprOrganList")
    public Result<Page<AprOrganVO>> aprOrganList(@RequestParam(defaultValue = "1") Integer pageNum, @RequestParam(defaultValue = "10") Integer pageSize,
                                                 Long organId, Boolean isIncluded, String organName, String code) {
        Page<AprOrganVO> page = new Page<>(pageNum, pageSize);
        page = aprOrganService.aprOrganList(page, organId, isIncluded, organName, code);
        return Result.success(page);
    }

    /**
     * 获取评定机构信息
     *
     * @param aprOrganId 评定机构id
     * @return 返回相关信息
     */
    @GetMapping("/getAprOrganInfo")
    public Result<ChAprOrgan> getAprOrganInfo(Long aprOrganId) {
        if (null == aprOrganId) {
            return Result.failed(ResultCode.REQUEST_PARAM_ERROR);
        }
        ChAprOrgan chAprOrgan = aprOrganService.getAprOrganInfo(aprOrganId);
        return Result.success(chAprOrgan);
    }

    /**
     * 更改评定机构状态
     *
     * @param aprOrganId 监管机构id
     * @param status     状态 有效：0；失效：1
     */
    @DeleteMapping("/updateAprOrganStatus")
    public Result updateAprOrganStatus(String aprOrganId, Short status) {
        if (StringUtils.isBlank(aprOrganId) || status == null || (status != 1 && status != 0)) {
            return Result.failed(ResultCode.REQUEST_PARAM_ERROR);
        }
        aprOrganService.updateAprOrganStatus(aprOrganId, status);
        return Result.success();
    }

    /**
     * 新增评定机构或更新评定机构信息(有apr_organ_id就更新,没有就新增)
     *
     * @param updateType 更新类型(1:账户信息修改,2:基本信息修改),新增不传
     */
    @DeleteMapping("/updateAprOrganStatus")
    public Result addOrUpdateAprOrgan(ChAprOrgan chAprOrgan, Short updateType) {
        if (chAprOrgan == null) {
            return Result.failed(ResultCode.REQUEST_PARAM_ERROR);
        }
        if (chAprOrgan.getAprOrganId() == null) {
            //新增
            if (StringUtils.isBlank(chAprOrgan.getOrganId())) {//适用机构
                return Result.failed(ResultCode.REQUEST_PARAM_ERROR);
            }
            if (StringUtils.isBlank(chAprOrgan.getDistrictProvincial()) || StringUtils.isBlank(chAprOrgan.getDistrictArea()) || StringUtils.isBlank(chAprOrgan.getDistrictCity())) {//所在省市区
                return Result.failed(ResultCode.REQUEST_PARAM_ERROR);
            }
            if (StringUtils.isBlank(chAprOrgan.getOrganName())) {//评定机构名称
                return Result.failed(ResultCode.REQUEST_PARAM_ERROR);
            }
            if (StringUtils.isBlank(chAprOrgan.getUnifiedSocialCreditCode())) {//统一社会信用代码
                return Result.failed(ResultCode.REQUEST_PARAM_ERROR);
            }
            if (chAprOrgan.getOrganTypeId() == null) {//机构类型id
                return Result.failed(ResultCode.REQUEST_PARAM_ERROR);
            }
            if (StringUtils.isBlank(chAprOrgan.getAcptProvincial()) || StringUtils.isBlank(chAprOrgan.getAcptCity()) || StringUtils.isBlank(chAprOrgan.getAcptArea()) || StringUtils.isBlank(chAprOrgan.getAcptAddress()) || StringUtils.isBlank(chAprOrgan.getAcptStreet())) {//机构详细地址
                return Result.failed(ResultCode.REQUEST_PARAM_ERROR);
            }
            if (StringUtils.isBlank(chAprOrgan.getLinkName())) {//机构联系人姓名
                return Result.failed(ResultCode.REQUEST_PARAM_ERROR);
            }
            if (StringUtils.isBlank(chAprOrgan.getLinkTel())) {//机构联系人手机号
                return Result.failed(ResultCode.REQUEST_PARAM_ERROR);
            }
            if (chAprOrgan.getGroupDetailId() == null) {//评定起点地址
                return Result.failed(ResultCode.REQUEST_PARAM_ERROR);
            }
            if (StringUtils.isBlank(chAprOrgan.getAccName())) {//银行账户名称
                return Result.failed(ResultCode.REQUEST_PARAM_ERROR);
            }
            if (StringUtils.isBlank(chAprOrgan.getBankNo())) {//银行账号
                return Result.failed(ResultCode.REQUEST_PARAM_ERROR);
            }
            if (StringUtils.isBlank(chAprOrgan.getBankDistrictProvincial()) || StringUtils.isBlank(chAprOrgan.getBankDistrictCity())) {//账号所属省市
                return Result.failed(ResultCode.REQUEST_PARAM_ERROR);
            }
            if (StringUtils.isBlank(chAprOrgan.getBankDistrictWebsite())) {//账号所属网点
                return Result.failed(ResultCode.REQUEST_PARAM_ERROR);
            }
            if (chAprOrgan.getCardType() == null) {//卡类型
                return Result.failed(ResultCode.REQUEST_PARAM_ERROR);
            }
        } else {
            //更新
            if (updateType != 1 && updateType != 2) {
                return Result.failed(ResultCode.REQUEST_PARAM_ERROR);
            }
            if (updateType == 1) {//账户信息修改
                if (StringUtils.isBlank(chAprOrgan.getAccName())) {//银行账户名称
                    return Result.failed(ResultCode.REQUEST_PARAM_ERROR);
                }
                if (StringUtils.isBlank(chAprOrgan.getBankNo())) {//银行账号
                    return Result.failed(ResultCode.REQUEST_PARAM_ERROR);
                }
                if (StringUtils.isBlank(chAprOrgan.getBankDistrictProvincial()) || StringUtils.isBlank(chAprOrgan.getBankDistrictCity())) {//账号所属省市
                    return Result.failed(ResultCode.REQUEST_PARAM_ERROR);
                }
                if (StringUtils.isBlank(chAprOrgan.getBankDistrictWebsite())) {//账号所属网点
                    return Result.failed(ResultCode.REQUEST_PARAM_ERROR);
                }
                if (chAprOrgan.getCardType() == null) {//卡类型
                    return Result.failed(ResultCode.REQUEST_PARAM_ERROR);
                }
            } else {//基本信息修改
                if (StringUtils.isBlank(chAprOrgan.getDistrictProvincial()) || StringUtils.isBlank(chAprOrgan.getDistrictArea()) || StringUtils.isBlank(chAprOrgan.getDistrictCity())) {//所在省市区
                    return Result.failed(ResultCode.REQUEST_PARAM_ERROR);
                }
                if (StringUtils.isBlank(chAprOrgan.getUnifiedSocialCreditCode())) {//统一社会信用代码
                    return Result.failed(ResultCode.REQUEST_PARAM_ERROR);
                }
                if (chAprOrgan.getOrganTypeId() == null) {//机构类型id
                    return Result.failed(ResultCode.REQUEST_PARAM_ERROR);
                }
                if (StringUtils.isBlank(chAprOrgan.getAcptArea()) || StringUtils.isBlank(chAprOrgan.getAcptAddress()) || StringUtils.isBlank(chAprOrgan.getAcptStreet())) {//机构详细地址
                    return Result.failed(ResultCode.REQUEST_PARAM_ERROR);
                }
                if (StringUtils.isBlank(chAprOrgan.getLinkName())) {//机构联系人姓名
                    return Result.failed(ResultCode.REQUEST_PARAM_ERROR);
                }
                if (StringUtils.isBlank(chAprOrgan.getLinkTel())) {//机构联系人手机号
                    return Result.failed(ResultCode.REQUEST_PARAM_ERROR);
                }
                if (chAprOrgan.getGroupDetailId() == null) {//评定起点地址
                    return Result.failed(ResultCode.REQUEST_PARAM_ERROR);
                }
            }
        }
        aprOrganService.addOrUpdateAprOrgan(chAprOrgan, updateType);
        return Result.success();
    }

}
